@@ -35,7 +35,7 @@
 #![doc(
     html_logo_url = "https://raw.githubusercontent.com/RustCrypto/meta/master/logo.svg",
     html_favicon_url = "https://raw.githubusercontent.com/RustCrypto/meta/master/logo.svg",
-    html_root_url = "https://docs.rs/crypto-bigint/0.2.0"
+    html_root_url = "https://docs.rs/crypto-bigint/0.2.1"
 )]
 #![forbid(unsafe_code, clippy::unwrap_used)]
 #![warn(missing_docs, rust_2018_idioms, unused_qualifications)]
@@ -64,9 +64,6 @@ pub use {
     generic_array::{self, typenum::consts},
 };
 
-#[cfg(not(any(target_pointer_width = "32", target_pointer_width = "64")))]
-compile_error!("this crate builds on 32-bit and 64-bit platforms only");
-
 /// Number of bytes in a [`Limb`].
 #[cfg(target_pointer_width = "32")]
 pub const LIMB_BYTES: usize = 4;
